@@ -24,10 +24,13 @@ import json
 import os
 import subprocess as sp
 import sys
-from typing import List, Optional, Tuple, TYPE_CHECKING
+from dataclasses import dataclass, field
+from datetime import timezone
+from typing import Dict, List, Optional, Tuple, TYPE_CHECKING
+from typing_extensions import Annotated
 
-from databind.core import datamodel, field
-from nr.parsing.date import timezone  # type: ignore
+from databind.core import annotations as A
+from nr.parsing.date import tzlocal
 
 from shut.model.requirements import Requirement
 from .base import (BaseTestDriver, Runtime, StackTrace, TestCase, TestCrashReport,
@@ -45,7 +48,7 @@ def load_report_file(report_file: str) -> TestRun:
   with open(report_file) as fp:
     raw = json.load(fp)
 
-  started_time = datetime.datetime.fromtimestamp(raw['created']).replace(tzinfo=timezone.local).astimezone(timezone.utc)
+  started_time = datetime.datetime.fromtimestamp(raw['created']).replace(tzinfo=tzlocal()).astimezone(timezone.utc)
   duration = raw['duration']
   status = TestStatus.PASSED if raw['exitcode'] == 0 else TestStatus.FAILED
   environment = TestEnvironment(raw['environment']['Python'], raw['environment']['Platform'])
@@ -66,6 +69,8 @@ def load_report_file(report_file: str) -> TestRun:
   for test in raw['tests']:
     failed_stage = next((test[k] for k in ('setup', 'call', 'teardown')
       if k in test and test[k]['outcome'] == 'failed'), None)
+    crash: Optional[TestCrashReport] = None
+    stdout: str = ''
     if failed_stage:
       crash = TestCrashReport(
         filename=failed_stage['crash']['path'],
@@ -75,10 +80,7 @@ def load_report_file(report_file: str) -> TestRun:
         longrepr=failed_stage['longrepr'],
       )
       stdout = failed_stage.get('stdout')
-    else:
-      crash = None
-      stdout = None
-    test_status = {'passed': TestStatus.PASSED, 'failed': TestStatus.FAILED, 'skipped': TestStatus.SKIPPED}[test['outcome']]
+    test_status = {'passed': TestStatus.PASSED, 'failed': TestStatus.FAILED, 'skipped': TestStatus.SKIPPED}[test['outcome'].lstrip('x')]
     tests.append(TestCase(
       name=test['nodeid'],
       duration=sum(test[k]['duration'] for k in ('setup', 'call', 'teardown') if k in test),
@@ -92,7 +94,8 @@ def load_report_file(report_file: str) -> TestRun:
   return TestRun(started_time, duration, status, environment, tests, errors)
 
 
-@datamodel
+@A.union.subtype(BaseTestDriver, 'pytest')
+@dataclass
 class PytestDriver(BaseTestDriver):
   """
   A driver for running unit tests using [Pytest][1].
@@ -102,7 +105,7 @@ class PytestDriver(BaseTestDriver):
 
   directory: Optional[str] = None
   args: List[str] = field(default_factory=lambda: ['-vv'])
-  report_file: str = field(default='.pytest-report.json', altname='report-file')
+  report_file: Annotated[str, A.alias('report-file')] = '.pytest-report.json'
 
   # BaseTestDriver
 
